@@ -19,26 +19,26 @@ class TorchCheckpointerCallback(ICheckpointerCallback):
         if isinstance(obj, (nn.DataParallel, nn.parallel.DistributedDataParallel)):
             obj = obj.module
         logpath = f"{logprefix}.pth"
-        if isinstance(obj, nn.Module):
+        if issubclass(obj.__class__, torch.nn.Module):
             torch.save(obj.state_dict(), logpath)
         else:
             torch.save(obj, logpath)
         return logpath
 
 
-class AccelerateCheckpointerCallback(ICheckpointerCallback):
+class EngineCheckpointerCallback(ICheckpointerCallback):
     def on_experiment_start(self, exp: "IExperiment") -> None:
-        assert isinstance(getattr(exp, "accelerator", None), Accelerator)
+        assert isinstance(getattr(exp, "engine", None), Accelerator)
 
     def save(self, exp: IExperiment, obj: Any, logprefix: str) -> str:
         logpath = f"{logprefix}.pth"
-        if isinstance(obj, nn.Module):
-            exp.accelerator.wait_for_everyone()
-            obj = exp.accelerator.unwrap_model(obj)
-            exp.accelerator.save(obj.state_dict(), logpath)
+        if issubclass(obj.__class__, torch.nn.Module):
+            exp.engine.wait_for_everyone()
+            obj = exp.engine.unwrap_model(obj)
+            exp.engine.save(obj.state_dict(), logpath)
         else:
-            exp.accelerator.save(obj, logpath)
+            exp.engine.save(obj, logpath)
         return logpath
 
 
-__all__ = [TorchCheckpointerCallback, AccelerateCheckpointerCallback]
+__all__ = [TorchCheckpointerCallback, EngineCheckpointerCallback]
